==> haskell-hstringtemplate-0.8.8-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hstringtemplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HStringTemplate
version:              0.8.8
visibility:           public
id:                   HStringTemplate-0.8.8-6u3ef8XQgD25xhNTj53xpE
key:                  HStringTemplate-0.8.8-6u3ef8XQgD25xhNTj53xpE
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             StringTemplate implementation in Haskell.
description:          A port of the Java library by Terrence Parr.
category:             Text
abi:                  8a1f6fe088375f46c1c84a4abadf20ab
exposed:              True
exposed-modules:
    Text.StringTemplate Text.StringTemplate.Base
    Text.StringTemplate.Classes Text.StringTemplate.GenericStandard
    Text.StringTemplate.QQ

hidden-modules:
    Text.StringTemplate.Instances Text.StringTemplate.Group
    Text.StringTemplate.Renderf

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HStringTemplate-0.8.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HStringTemplate-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hstringtemplate
hs-libraries:         HSHStringTemplate-0.8.8-6u3ef8XQgD25xhNTj53xpE
depends:
    array-0.5.4.0 base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 directory-1.3.6.2
    filepath-1.4.2.2 mtl-2.2.2
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7 parsec-3.1.15.0
    pretty-1.1.3.6 syb-0.7.2.4-Dpcmd8sO2dOH7fqJn9vSHY
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:
    /usr/share/doc/haskell-hstringtemplate/html/HStringTemplate.haddock

haddock-html:         /usr/share/doc/haskell-hstringtemplate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hstringtemplate-0.8.8-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hstringtemplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HStringTemplate
version:              0.8.8
visibility:           public
id:                   HStringTemplate-0.8.8-CAgNJRpN2KDCrSIotzwnN
key:                  HStringTemplate-0.8.8-CAgNJRpN2KDCrSIotzwnN
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             StringTemplate implementation in Haskell.
description:          A port of the Java library by Terrence Parr.
category:             Text
abi:                  f26f9c02e6e012d6fe28d164a7dff020
exposed:              True
exposed-modules:
    Text.StringTemplate Text.StringTemplate.Base
    Text.StringTemplate.Classes Text.StringTemplate.GenericStandard
    Text.StringTemplate.QQ

hidden-modules:
    Text.StringTemplate.Instances Text.StringTemplate.Group
    Text.StringTemplate.Renderf

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HStringTemplate-0.8.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HStringTemplate-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hstringtemplate
hs-libraries:         HSHStringTemplate-0.8.8-CAgNJRpN2KDCrSIotzwnN
depends:
    array-0.5.4.0 base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 directory-1.3.6.2
    filepath-1.4.2.2 mtl-2.2.2
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7 parsec-3.1.15.0
    pretty-1.1.3.6 syb-0.7.2.4-LOCaeanCkJLLhNbs0SZs6t
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:
    /usr/share/doc/haskell-hstringtemplate/html/HStringTemplate.haddock

haddock-html:         /usr/share/doc/haskell-hstringtemplate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
